"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const utils_1 = require("../../utils");
const fs_1 = require("fs");
const errors_1 = require("../../errors");
const baseMetadataTransformer_1 = require("./baseMetadataTransformer");
/**
 * The default metadata transformer.
 *
 * If a metadata type doesn't have a transformer assigned to it, this one is used
 * during the conversion process. It leaves the component's metadata xml and source
 * files as-is.
 */
class DefaultMetadataTransformer extends baseMetadataTransformer_1.BaseMetadataTransformer {
    toMetadataFormat() {
        const result = { component: this.component, writeInfos: [] };
        let xmlDest = this.component.getPackageRelativePath(this.component.xml);
        if (this.component.content) {
            for (const source of this.component.walkContent()) {
                result.writeInfos.push({
                    source: fs_1.createReadStream(source),
                    relativeDestination: this.component.getPackageRelativePath(source),
                });
            }
        }
        else {
            xmlDest = xmlDest.slice(0, xmlDest.lastIndexOf(utils_1.META_XML_SUFFIX));
        }
        result.writeInfos.push({
            source: fs_1.createReadStream(this.component.xml),
            relativeDestination: xmlDest,
        });
        return result;
    }
    toSourceFormat() {
        throw new errors_1.LibraryError('error_convert_not_implemented', ['source', this.component.type.name]);
    }
}
exports.DefaultMetadataTransformer = DefaultMetadataTransformer;
//# sourceMappingURL=defaultMetadataTransformer.js.map