"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("ignore/index");
const path_1 = require("path");
const fs_1 = require("fs");
const constants_1 = require("../utils/constants");
const fileSystemHandler_1 = require("../utils/fileSystemHandler");
const DEFAULT_IGNORE = [
    '**/*.dup',
    '.*',
    'package2-descriptor.json',
    'package2-manifest.json',
];
class ForceIgnore {
    constructor(forceIgnorePath = '') {
        try {
            // add the default ignore paths, and then parse the .forceignore file
            this.parser = index_1.default().add(DEFAULT_IGNORE).add(fs_1.readFileSync(forceIgnorePath, 'utf-8'));
            this.forceIgnoreDirectory = path_1.dirname(forceIgnorePath);
        }
        catch (e) {
            // TODO: log no force ignore
        }
    }
    /**
     * Performs an upward directory search for a `.forceignore` file and returns a
     * `ForceIgnore` object based on the result. If there is no `.forceignore` file,
     * the returned `ForceIgnore` object will accept everything.
     *
     * @param seed Path to begin the `.forceignore` search from
     */
    static findAndCreate(seed) {
        let potentialForceIgnorePath = '';
        const projectConfigPath = fileSystemHandler_1.searchUp(seed, constants_1.FORCE_IGNORE_FILE);
        if (projectConfigPath) {
            potentialForceIgnorePath = path_1.join(path_1.dirname(projectConfigPath), constants_1.FORCE_IGNORE_FILE);
        }
        return new ForceIgnore(potentialForceIgnorePath);
    }
    denies(fsPath) {
        let denies = false;
        if (this.parser) {
            denies = this.parser.ignores(path_1.relative(this.forceIgnoreDirectory, fsPath));
        }
        return denies;
    }
    accepts(fsPath) {
        let accepts = true;
        if (this.parser) {
            accepts = !this.parser.ignores(path_1.relative(this.forceIgnoreDirectory, fsPath));
        }
        return accepts;
    }
}
exports.ForceIgnore = ForceIgnore;
//# sourceMappingURL=forceIgnore.js.map