"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const path_1 = require("path");
exports.mockRegistry = {
    types: {
        kathybates: {
            id: 'kathybates',
            directoryName: 'kathys',
            inFolder: true,
            name: 'KathyBates',
            suffix: 'kathy',
        },
        keanureeves: {
            id: 'keanureeves',
            directoryName: 'keanus',
            inFolder: false,
            name: 'KeanuReeves',
            suffix: 'keanu',
        },
        tinafey: {
            id: 'tinafey',
            directoryName: 'tinas',
            inFolder: true,
            name: 'TinaFey',
        },
        dwaynejohnson: {
            id: 'dwaynejohnson',
            directoryName: 'dwaynes',
            inFolder: false,
            name: 'DwayneJohnson',
        },
        tarajihenson: {
            id: 'tarajihenson',
            directoryName: 'tarajis',
            inFolder: false,
            name: 'TarajiHenson',
        },
        simonpegg: {
            id: 'simonpegg',
            directoryName: 'simons',
            inFolder: false,
            name: 'SimonPegg',
        },
        tinafeyfolder: {
            id: 'tinafeyfolder',
            directoryName: 'tinas',
            inFolder: false,
            name: 'TinaFeyFolder',
            suffix: 'tinafeyFolder',
        },
        genewilder: {
            id: 'genewilder',
            directoryName: 'genes',
            inFolder: false,
            name: 'GeneWilder',
            suffix: 'gene',
        },
        reginaking: {
            id: 'reginaking',
            directoryName: 'reginas',
            inFolder: false,
            name: 'ReginaKing',
            suffix: 'regina',
            children: {
                types: {
                    x: {
                        id: 'x',
                        directoryName: 'xs',
                        name: 'X',
                        suffix: 'x',
                    },
                    y: {
                        id: 'y',
                        directoryName: 'ys',
                        name: 'Y',
                        suffix: 'y',
                    },
                },
                suffixes: {
                    x: 'x',
                    y: 'y',
                },
            },
        },
        seanconnerys: {
            id: 'seanconnerys',
            directoryName: 'seans',
            inFolder: true,
            name: 'SeanConnery',
            suffix: 'sean',
        },
    },
    suffixes: {
        kathy: 'kathybates',
        keanu: 'keanureeves',
        missing: 'typewithoutdef',
        tinafeyFolder: 'tinafeyfolder',
        genewilder: 'gene',
        reginaking: 'regina',
        sean: 'seanconnerys',
    },
    mixedContent: {
        dwaynes: 'dwaynejohnson',
        tarajis: 'tarajihenson',
        simons: 'simonpegg',
        tinas: 'tinafey',
        reginas: 'reginaking',
    },
    strategies: {
        keanureeves: { adapter: 'matchingContentFile', transformer: 'standard' },
        tinafey: { adapter: 'mixedContent', transformer: 'mixedContent' },
        tarajihenson: { adapter: 'mixedContent', transformer: 'mixedContent' },
        dwaynejohnson: { adapter: 'mixedContent', transformer: 'mixedContent' },
        simonpegg: { adapter: 'bundle', transformer: 'bundle' },
        reginaking: { adapter: 'decomposed', transformer: 'decomposed' },
        genewilder: { adapter: 'badAdapterId', transformer: 'badAdapterId' },
    },
    apiVersion: '48.0',
};
const keanu = require("./keanuConstants");
exports.keanu = keanu;
const kathy = require("./kathyConstants");
exports.kathy = kathy;
const simon = require("./simonConstants");
exports.simon = simon;
const taraji = require("./tarajiConstants");
exports.taraji = taraji;
const tina = require("./tinaConstants");
exports.tina = tina;
const gene = require("./geneConstants");
exports.gene = gene;
const regina = require("./reginaConstants");
exports.regina = regina;
const sean = require("./seanConstants");
exports.sean = sean;
// Mixed content
exports.DWAYNE_DIR = path_1.join('path', 'to', 'dwaynes');
exports.DWAYNE_XML_NAME = 'a.dwayne-meta.xml';
exports.DWAYNE_XML = path_1.join(exports.DWAYNE_DIR, exports.DWAYNE_XML_NAME);
exports.DWAYNE_SOURCE_NAME = 'a.xyz';
exports.DWAYNE_SOURCE = path_1.join(exports.DWAYNE_DIR, exports.DWAYNE_SOURCE_NAME);
//# sourceMappingURL=index.js.map